@@ -28,9 +28,11 @@ class film:
             self.num=0
             self.fps=cv.GetCaptureProperty(self.capture,cv.CV_CAP_PROP_FPS)
             self.framecount=cv.GetCaptureProperty(self.capture,cv.CV_CAP_PROP_FRAME_COUNT)
-            assert 1.0*self.filesize/self.framecount > 2000, "fichier aberrant en taille"
+            #print self.framecount, self.fps
+            #print self.filesize, 1.0*self.filesize/self.framecount
+            assert 1.0*self.filesize/self.framecount > 1800.0, "fichier aberrant en taille"
             self.ok=True
-        except:
+        except AssertionError:
             pass
 
     def __int__(self):
